@@ -4,6 +4,13 @@ from vista_api_client.api_resources.api_resource import ApiResource, HttpMethods
 
 class Grants(ApiResource):
     def list(self, user_id, action, resource_id, resource_type, attribute, org_id):
+        user_id = user_id or ''
+        action = action or ''
+        resource_id = resource_id or ''
+        resource_type = resource_type or ''
+        attribute = attribute or ''
+        org_id = org_id or ''
+
         return self.dispatch('/v1/grants', HttpMethods.GET, {
             'id': user_id,
             'action': action,
